@@ -12,7 +12,7 @@ from typing import Dict, Callable, Any
 
 if typing.TYPE_CHECKING:
     from .poll import PollData
-    from .pubsub import PubSubData, PubSubPointRedemption, PubSubBits
+    from .pubsub import PubSubData, PubSubPointRedemption, PubSubBits, PubSubModerationAction
 
 from .channel import Channel
 from .command import Command
@@ -205,6 +205,13 @@ class Mod:
         :param data: data specific to the bits being sent
         """
 
+    async def on_pubsub_moderation_action(self, raw: 'PubSubData', data: 'PubSubModerationAction'):
+        """
+        triggered when a moderator does a moderation action such as ban/unban/timeout
+        :param raw: the raw pubsub message
+        :param data: data specific to the moderation action taken
+        """
+
     # endregion
 
 
